/* jshint globalstrict:true */
'use strict';

const STYLES_CONTAINER_ID = 'locrmaps-styles';

/**
 * @param {HTMLSelectElement} select
 */
function trySettingOverlayTemplateBaseColor(select) {
    if (!(select.options[select.selectedIndex] instanceof HTMLOptionElement)) {
        window.console.warn('trySettingOverlayTemplateBaseColor: No option selected');
        return;
    }
    if (!wp || !wp.hooks) {
        window.console.warn('trySettingOverlayTemplateBaseColor: wp.hooks is not available');
        return;
    }

    let baseColorValue = 'white';

    const selectioOption = select.options[select.selectedIndex];
    const dataOverlayTemplateBaseColorAttr = selectioOption.attributes.getNamedItem('data-overlay-template-base-color');
    if (dataOverlayTemplateBaseColorAttr instanceof window.Attr) {
        baseColorValue = dataOverlayTemplateBaseColorAttr.value;
    }

    const overlayTemplatesBaseColorsElement = document.getElementById('locrmaps-overlay-templates-base-colors');
    if (overlayTemplatesBaseColorsElement instanceof HTMLSelectElement) {
        if (typeof overlayTemplatesBaseColorsElement.selectOptionByValue === 'function') {
            overlayTemplatesBaseColorsElement.selectOptionByValue(baseColorValue);
        }
    }

    wp.hooks.doAction( 'locrMAPSForWooCommerceSetOverlayTemplateBaseColor', { value: baseColorValue } );
}

/**
 * @param {HTMLSelectElement} select
 */
function trySettingOverlayTemplateTextColor(select) {
    if (!(select.options[select.selectedIndex] instanceof HTMLOptionElement)) {
        window.console.warn('trySettingOverlayTemplateTextColor: No option selected');
        return;
    }
    if (!wp || !wp.hooks) {
        window.console.warn('trySettingOverlayTemplateTextColor: wp.hooks is not available');
        return;
    }

    let textColorValue = 'black';

    const selectioOption = select.options[select.selectedIndex];
    const dataOverlayTemplateTextColorAttr = selectioOption.attributes.getNamedItem('data-overlay-template-text-color');
    if (dataOverlayTemplateTextColorAttr instanceof window.Attr) {
        textColorValue = dataOverlayTemplateTextColorAttr.value;
    }

    const overlayTemplatesTextColorsElement = document.getElementById('locrmaps-overlay-templates-text-colors');
    if (overlayTemplatesTextColorsElement instanceof HTMLSelectElement) {
        if (typeof overlayTemplatesTextColorsElement.selectOptionByValue === 'function') {
            overlayTemplatesTextColorsElement.selectOptionByValue(textColorValue);
        }
    }

    wp.hooks.doAction( 'locrMAPSForWooCommerceSetOverlayTemplateTextColor', { value: textColorValue } );
}

document.addEventListener('DOMContentLoaded', function() {
    let stylesElement;

    const locrmapsStylesQuerySelector = document.getElementById('locrmaps-styles-query-selector');
    if (locrmapsStylesQuerySelector instanceof HTMLInputElement && locrmapsStylesQuerySelector.value) {
        stylesElement = document.querySelector(locrmapsStylesQuerySelector.value);
    }
    if (!stylesElement) {
        stylesElement = document.getElementById(STYLES_CONTAINER_ID);
    }

    if (stylesElement instanceof HTMLSelectElement) {
        stylesElement.addEventListener('change', function(event) {
            if (!(event.target instanceof HTMLSelectElement)) {
                return;
            }

            document.dispatchEvent(new CustomEvent('locr.locrmaps.set-style', { detail: { style: event.target.value } }));
            trySettingOverlayTemplateBaseColor(event.target);
            trySettingOverlayTemplateTextColor(event.target);
        });

        if (stylesElement.value) {
            document.dispatchEvent(new CustomEvent('locr.locrmaps.set-style', { detail: { style: stylesElement.value } }));
            trySettingOverlayTemplateBaseColor(stylesElement);
            trySettingOverlayTemplateTextColor(stylesElement);

            if (wp?.hooks) {
                wp.hooks.addAction(
                    'locrMAPSInitialized',
                    'locr/locrmaps',
                    () => {
                        document.dispatchEvent(new CustomEvent('locr.locrmaps.set-style', { detail: { style: stylesElement.value } }));
                        trySettingOverlayTemplateBaseColor(stylesElement);
                        trySettingOverlayTemplateTextColor(stylesElement);
                    }
                );
            }
        }
    }
});
